
/* Generated data (by glib-mkenums) */

#include "gtr-enum-types.h"

/* enumerations from "gtr-message-table.h" */
#include "gtr-message-table.h"

GType
gtr_message_table_navigation_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GTR_NAVIGATE_PREV,
			  "GTR_NAVIGATE_PREV",
			  "prev" },
			{ GTR_NAVIGATE_NEXT,
			  "GTR_NAVIGATE_NEXT",
			  "next" },
			{ GTR_NAVIGATE_FIRST,
			  "GTR_NAVIGATE_FIRST",
			  "first" },
			{ GTR_NAVIGATE_LAST,
			  "GTR_NAVIGATE_LAST",
			  "last" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GtrMessageTableNavigation"),
				values);
	}
	return the_type;
}

/* enumerations from "gtr-msg.h" */
#include "gtr-msg.h"

GType
gtr_msg_status_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GTR_MSG_STATUS_UNTRANSLATED,
			  "GTR_MSG_STATUS_UNTRANSLATED",
			  "untranslated" },
			{ GTR_MSG_STATUS_FUZZY,
			  "GTR_MSG_STATUS_FUZZY",
			  "fuzzy" },
			{ GTR_MSG_STATUS_TRANSLATED,
			  "GTR_MSG_STATUS_TRANSLATED",
			  "translated" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GtrMsgStatus"),
				values);
	}
	return the_type;
}

/* enumerations from "gtr-po.h" */
#include "gtr-po.h"

GType
gtr_po_state_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GTR_PO_STATE_SAVED,
			  "GTR_PO_STATE_SAVED",
			  "saved" },
			{ GTR_PO_STATE_MODIFIED,
			  "GTR_PO_STATE_MODIFIED",
			  "modified" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GtrPoState"),
				values);
	}
	return the_type;
}

/* enumerations from "gtr-tab.h" */
#include "gtr-tab.h"

GType
gtr_tab_move_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GTR_TAB_MOVE_NONE,
			  "GTR_TAB_MOVE_NONE",
			  "none" },
			{ GTR_TAB_MOVE_NEXT,
			  "GTR_TAB_MOVE_NEXT",
			  "next" },
			{ GTR_TAB_MOVE_PREV,
			  "GTR_TAB_MOVE_PREV",
			  "prev" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GtrTabMove"),
				values);
	}
	return the_type;
}

GType
gtr_tab_placement_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GTR_TAB_PLACEMENT_NONE,
			  "GTR_TAB_PLACEMENT_NONE",
			  "none" },
			{ GTR_TAB_PLACEMENT_TOP,
			  "GTR_TAB_PLACEMENT_TOP",
			  "top" },
			{ GTR_TAB_PLACEMENT_BOTTOM,
			  "GTR_TAB_PLACEMENT_BOTTOM",
			  "bottom" },
			{ GTR_TAB_PLACEMENT_RIGHT,
			  "GTR_TAB_PLACEMENT_RIGHT",
			  "right" },
			{ GTR_TAB_PLACEMENT_LEFT,
			  "GTR_TAB_PLACEMENT_LEFT",
			  "left" },
			{ GTR_TAB_PLACEMENT_CENTER,
			  "GTR_TAB_PLACEMENT_CENTER",
			  "center" },
			{ GTR_TAB_PLACEMENT_FLOATING,
			  "GTR_TAB_PLACEMENT_FLOATING",
			  "floating" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GtrTabPlacement"),
				values);
	}
	return the_type;
}

/* enumerations from "gtr-view.h" */
#include "gtr-view.h"

GType
gtr_search_flags_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GTR_SEARCH_DONT_SET_FLAGS,
			  "GTR_SEARCH_DONT_SET_FLAGS",
			  "dont-set-flags" },
			{ GTR_SEARCH_ENTIRE_WORD,
			  "GTR_SEARCH_ENTIRE_WORD",
			  "entire-word" },
			{ GTR_SEARCH_CASE_SENSITIVE,
			  "GTR_SEARCH_CASE_SENSITIVE",
			  "case-sensitive" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GtrSearchFlags"),
				values);
	}
	return the_type;
}


/* Generated data ends here */

