
/* Generated data (by glib-mkenums) */

#ifndef __GTR_ENUM_TYPES_H__
#define __GTR_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "gtr-message-table.h" */

#define GTR_TYPE_MESSAGE_TABLE_NAVIGATION	(gtr_message_table_navigation_get_type())
GType gtr_message_table_navigation_get_type	(void) G_GNUC_CONST;

/* Enumerations from "gtr-msg.h" */

#define GTR_TYPE_MSG_STATUS	(gtr_msg_status_get_type())
GType gtr_msg_status_get_type	(void) G_GNUC_CONST;

/* Enumerations from "gtr-po.h" */

#define GTR_TYPE_PO_STATE	(gtr_po_state_get_type())
GType gtr_po_state_get_type	(void) G_GNUC_CONST;

/* Enumerations from "gtr-tab.h" */

#define GTR_TYPE_TAB_MOVE	(gtr_tab_move_get_type())
GType gtr_tab_move_get_type	(void) G_GNUC_CONST;

#define GTR_TYPE_TAB_PLACEMENT	(gtr_tab_placement_get_type())
GType gtr_tab_placement_get_type	(void) G_GNUC_CONST;

/* Enumerations from "gtr-view.h" */

#define GTR_TYPE_SEARCH_FLAGS	(gtr_search_flags_get_type())
GType gtr_search_flags_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* __GEDIT_ENUM_TYPES_H__ */

/* Generated data ends here */

